@@ -1,6 +1,7 @@
-use clap::builder::{PossibleValuesParser, TypedValueParser};
 use clap::Args;
+use clap::builder::{PossibleValuesParser, TypedValueParser};
 use pkgcruft::reporter::Reporter;
+use pkgcruft::scan::Scanner;
 use strum::VariantNames;
 
 #[derive(Debug, Args)]
@@ -32,15 +33,16 @@ pub(crate) struct ReporterOptions {
 }
 
 impl ReporterOptions {
-    pub(crate) fn collapse(&self) -> Reporter {
+    pub(crate) fn collapse(&self, scanner: Option<&Scanner>) -> Reporter {
         let mut reporter = self.reporter.clone();
 
-        if let Reporter::Format(r) = &mut reporter {
-            r.format = self.format.clone().unwrap_or_default();
-        }
-
-        if let Reporter::Stats(r) = &mut reporter {
-            r.sort_by = self.stats.clone().unwrap_or_default();
+        match &mut reporter {
+            Reporter::Format(r) => r.format = self.format.clone().unwrap_or_default(),
+            Reporter::Stats(r) => r.sort_by = self.stats.clone().unwrap_or_default(),
+            Reporter::Time(r) => {
+                r.stats = scanner.map(|s| s.stats().clone()).unwrap_or_default()
+            }
+            _ => (),
         }
 
         reporter
