@@ -7,14 +7,24 @@ use pkgcraft::dep::Flatten;
 use pkgcraft::pkg::ebuild::EbuildPkg;
 use pkgcraft::pkg::ebuild::metadata::Key::{self, BDEPEND, DEPEND};
 use pkgcraft::repo::{EbuildRepo, PkgRepository};
-use pkgcraft::restrict::Restrict;
+use pkgcraft::restrict::{Restrict, Scope};
 use strum::{AsRefStr, Display, EnumIter, IntoEnumIterator};
 
 use crate::report::ReportKind::PythonUpdate;
 use crate::scan::ScannerRun;
+use crate::source::SourceKind;
 use crate::utils::{impl_targets, use_starts_with};
 
-use super::EbuildPkgCheck;
+use super::Context::GentooInherited;
+
+super::register! {
+    kind: super::CheckKind::PythonUpdate,
+    reports: &[PythonUpdate],
+    scope: Scope::Version,
+    sources: &[SourceKind::EbuildPkg],
+    context: &[GentooInherited],
+    create,
+}
 
 static IMPL_PKG: &str = "dev-lang/python";
 static IUSE_PREFIXES: &[&str] = &["python_targets_", "python_single_target_"];
@@ -48,13 +58,13 @@ impl Eclass {
     }
 }
 
-pub(super) fn create(run: &ScannerRun) -> impl EbuildPkgCheck + 'static {
-    Check {
+pub(super) fn create(run: &ScannerRun) -> super::Runner {
+    Box::new(Check {
         targets: Eclass::iter()
             .map(|e| (e, e.targets(&run.repo).collect()))
             .collect(),
         dep_targets: Default::default(),
-    }
+    })
 }
 
 struct Check {
@@ -62,8 +72,6 @@ struct Check {
     dep_targets: DashMap<Restrict, Option<HashSet<String>>>,
 }
 
-super::register!(Check, super::Check::PythonUpdate);
-
 /// Determine the set of compatible targets for a dependency.
 fn dep_targets(pkg: EbuildPkg) -> HashSet<String> {
     pkg.iuse()
@@ -86,7 +94,7 @@ impl Check {
         &self,
         repo: &EbuildRepo,
         dep: R,
-    ) -> Option<MappedRef<Restrict, Option<HashSet<String>>, HashSet<String>>> {
+    ) -> Option<MappedRef<'_, Restrict, Option<HashSet<String>>, HashSet<String>>> {
         let restrict = dep.into();
         self.dep_targets
             .entry(restrict.clone())
@@ -102,8 +110,8 @@ impl Check {
     }
 }
 
-impl EbuildPkgCheck for Check {
-    fn run(&self, pkg: &EbuildPkg, run: &ScannerRun) {
+impl super::CheckRun for Check {
+    fn run_ebuild_pkg(&self, pkg: &EbuildPkg, run: &ScannerRun) {
         let Some(eclass) = Eclass::iter().find(|x| pkg.inherited().contains(x.as_ref()))
         else {
             return;
@@ -136,16 +144,20 @@ impl EbuildPkgCheck for Check {
         }
 
         // drop targets with missing dependencies
-        for dep_targets in deps
+        for dep in deps
             .iter()
             .filter(|x| use_starts_with(x, IUSE_PREFIXES))
-            .filter_map(|dep| self.get_targets(&run.repo, dep.no_use_deps()))
+            .map(|x| x.no_use_deps())
         {
-            targets.retain(|&x| dep_targets.contains(x));
-            if targets.is_empty() {
-                // no updates available
-                return;
+            if let Some(dep_targets) = self.get_targets(&run.repo, dep.no_use_deps()) {
+                targets.retain(|&x| dep_targets.contains(x));
+                if !targets.is_empty() {
+                    continue;
+                }
             }
+
+            // no updates available
+            return;
         }
 
         PythonUpdate
