@@ -6,20 +6,20 @@ use std::str::FromStr;
 use std::sync::LazyLock;
 
 use camino::{Utf8Path, Utf8PathBuf};
-use colored::Color;
 use indexmap::IndexSet;
+use owo_colors::OwoColorize;
 use pkgcraft::bash::Node;
 use pkgcraft::cli::TriState;
 use pkgcraft::dep::{Cpn, Cpv};
-use pkgcraft::repo::{ebuild::EbuildRepo, Repository};
+use pkgcraft::repo::{EbuildRepo, Repository};
 use pkgcraft::restrict::{Restrict, Restriction, Scope};
 use regex::Regex;
 use serde::{Deserialize, Serialize};
 use strum::{AsRefStr, Display, EnumIter, EnumString};
 
-use crate::check::{Check, Context};
-use crate::scan::ScannerRun;
 use crate::Error;
+use crate::check::{Check, CheckKind, Context};
+use crate::scan::ScannerRun;
 
 /// The severity of the report.
 #[derive(
@@ -34,18 +34,6 @@ pub enum ReportLevel {
     Info,
 }
 
-impl From<ReportLevel> for Color {
-    fn from(level: ReportLevel) -> Self {
-        match level {
-            ReportLevel::Critical => Color::Red,
-            ReportLevel::Error => Color::TrueColor { r: 255, g: 140, b: 0 },
-            ReportLevel::Warning => Color::Yellow,
-            ReportLevel::Style => Color::Cyan,
-            ReportLevel::Info => Color::Green,
-        }
-    }
-}
-
 #[derive(Debug, PartialEq, Eq, PartialOrd, Ord, Hash, Clone, Copy)]
 pub enum RangeOrValue<T: Eq + Copy> {
     Value(T),
@@ -195,6 +183,12 @@ impl From<Check> for ReportSet {
     }
 }
 
+impl From<CheckKind> for ReportSet {
+    fn from(value: CheckKind) -> Self {
+        Self::Check(value.into())
+    }
+}
+
 impl From<Context> for ReportSet {
     fn from(value: Context) -> Self {
         Self::Context(value)
@@ -259,12 +253,12 @@ impl fmt::Display for ReportSet {
 
 impl ReportSet {
     /// Return true if the related reports should be added to the selected set.
-    pub fn selected(&self) -> bool {
+    fn selected(&self) -> bool {
         matches!(self, Self::Report(_) | Self::Check(_))
     }
 
     /// Expand a report set into an iterator of its variants.
-    pub fn expand<'a>(
+    pub(crate) fn expand<'a>(
         self,
         default: &'a IndexSet<ReportKind>,
         supported: &'a IndexSet<ReportKind>,
@@ -277,11 +271,11 @@ impl ReportSet {
                     .filter(|r| r.finish_check(Scope::Repo))
                     .copied(),
             ),
-            Self::Check(check) => Box::new(check.reports().iter().copied()),
+            Self::Check(check) => Box::new(check.reports.iter().copied()),
             Self::Context(context) => Box::new(
                 Check::iter_report(supported)
-                    .filter(move |x| x.context().contains(&context))
-                    .flat_map(|x| x.reports())
+                    .filter(move |x| x.context.contains(&context))
+                    .flat_map(|x| x.reports)
                     .copied(),
             ),
             Self::Level(range) => Box::new(
@@ -701,6 +695,18 @@ impl ReportKind {
         }
     }
 
+    /// Render the report variant into a string using its defined level color.
+    pub fn colorize(&self) -> String {
+        let s = self.as_ref();
+        match self.level() {
+            ReportLevel::Critical => s.red().to_string(),
+            ReportLevel::Error => s.fg_rgb::<255, 140, 0>().to_string(),
+            ReportLevel::Warning => s.yellow().to_string(),
+            ReportLevel::Style => s.cyan().to_string(),
+            ReportLevel::Info => s.green().to_string(),
+        }
+    }
+
     /// Return the scope of the report variant.
     ///
     /// This is the minimum scope at which the report is handled. For example, a variant
@@ -805,7 +811,7 @@ impl ReportKind {
     /// Return the sorted set of reports enabled by default for an ebuild repo.
     pub fn defaults(repo: &EbuildRepo) -> IndexSet<Self> {
         let mut set: IndexSet<_> = Check::iter_default(repo)
-            .flat_map(|x| x.reports())
+            .flat_map(|x| x.reports)
             .copied()
             .collect();
         set.sort_unstable();
@@ -816,7 +822,7 @@ impl ReportKind {
     pub fn supported<T: Into<Scope>>(repo: &EbuildRepo, value: T) -> IndexSet<Self> {
         let scope = value.into();
         let mut set: IndexSet<_> = Check::iter_supported(repo, scope)
-            .flat_map(|c| c.reports())
+            .flat_map(|c| c.reports)
             .filter(|r| scope >= r.scope())
             .copied()
             .collect();
@@ -965,6 +971,18 @@ impl PartialOrd for ReportScope {
     }
 }
 
+impl PartialEq<Scope> for ReportScope {
+    fn eq(&self, other: &Scope) -> bool {
+        self.scope() == *other
+    }
+}
+
+impl PartialOrd<Scope> for ReportScope {
+    fn partial_cmp(&self, other: &Scope) -> Option<Ordering> {
+        Some(self.scope().cmp(other))
+    }
+}
+
 impl fmt::Debug for ReportScope {
     fn fmt(&self, f: &mut fmt::Formatter) -> fmt::Result {
         match self {
@@ -1021,8 +1039,9 @@ impl Report {
 
     /// Deserialize a JSON string into a [`Report`].
     pub fn from_json(data: &str) -> crate::Result<Self> {
-        serde_json::from_str(data)
-            .map_err(|e| Error::InvalidValue(format!("failed deserializing report: {e}")))
+        serde_json::from_str(data).map_err(|e| {
+            Error::InvalidValue(format!("failed deserializing report JSON: {data}: {e}"))
+        })
     }
 }
 
@@ -1096,24 +1115,24 @@ impl<'a, R: BufRead> Iter<'a, R> {
     /// Determine if a given [`Report`] should be filtered.
     fn filtered(&self, report: &Report) -> bool {
         // skip excluded report variants
-        if let Some(reports) = self.reports {
-            if !reports.contains(&report.kind) {
-                return true;
-            }
+        if let Some(reports) = self.reports
+            && !reports.contains(&report.kind)
+        {
+            return true;
         }
 
         // skip excluded scope variants
-        if let Some(scopes) = self.scopes {
-            if !scopes.contains(&report.scope().scope()) {
-                return true;
-            }
+        if let Some(scopes) = self.scopes
+            && !scopes.contains(&report.scope().scope())
+        {
+            return true;
         }
 
         // skip excluded restrictions
-        if let Some(filter) = self.restrict {
-            if !filter.matches(report) {
-                return true;
-            }
+        if let Some(filter) = self.restrict
+            && !filter.matches(report)
+        {
+            return true;
         }
 
         false
@@ -1137,7 +1156,9 @@ impl<R: BufRead> Iterator for Iter<'_, R> {
                     err => return Some(err),
                 },
                 Err(e) => {
-                    return Some(Err(Error::InvalidValue(format!("failed reading line: {e}"))))
+                    return Some(Err(Error::InvalidValue(format!(
+                        "failed reading line: {e}"
+                    ))));
                 }
             }
         }
@@ -1248,7 +1269,7 @@ mod tests {
         assert!(selected.is_empty());
         let checks: IndexSet<_> = Check::iter_report(&enabled).collect();
         // repo specific checks enabled when scanning the matching repo
-        assert!(checks.contains(&Check::Header));
+        assert!(checks.contains(&CheckKind::Header));
 
         // default checks
         let repo = data.ebuild_repo("qa-primary").unwrap();
@@ -1257,11 +1278,11 @@ mod tests {
         let (enabled, selected) = ReportTarget::collapse([], &defaults, &supported).unwrap();
         assert!(selected.is_empty());
         let checks: IndexSet<_> = Check::iter_report(&enabled).collect();
-        assert!(checks.contains(&Check::Dependency));
+        assert!(checks.contains(&CheckKind::Dependency));
         // optional checks aren't run by default when scanning
-        assert!(!checks.contains(&Check::UnstableOnly));
+        assert!(!checks.contains(&CheckKind::UnstableOnly));
         // repo specific checks aren't run by default when scanning non-matching repo
-        assert!(!checks.contains(&Check::Header));
+        assert!(!checks.contains(&CheckKind::Header));
 
         // non-default reports aren't enabled when their matching level is targeted
         let report = ReportKind::HeaderInvalid;
