@@ -10,7 +10,7 @@ use pkgcraft::restrict::{Restrict, Scope, TryIntoRestrict};
 use pkgcraft::utils::bounded_jobs;
 use tracing::{info, warn};
 
-use crate::check::Check;
+use crate::check::{Check, CheckRunner};
 use crate::error::Error;
 use crate::ignore::Ignore;
 use crate::iter::{ReportIter, ReportSender};
@@ -148,7 +148,7 @@ impl Scanner {
 
         // determine enabled checks -- errors if incompatible check is selected
         let selected = Check::iter_report(&selected).collect();
-        run.checks = Check::iter_report(&enabled)
+        run.runners = Check::iter_report(&enabled)
             .unique()
             .sorted()
             .map(|check| {
@@ -159,7 +159,7 @@ impl Scanner {
                 } else if let Some(scope) = check.scoped(run.scope) {
                     Err(Error::CheckInit(check, format!("requires {scope} scope")))
                 } else {
-                    Ok(check)
+                    Ok(check.to_runner(&run))
                 }
             })
             .filter(|result| {
@@ -185,7 +185,7 @@ pub(crate) struct ScannerRun {
     force: bool,
     pub(crate) jobs: usize,
     pub(crate) filters: IndexSet<PkgFilter>,
-    pub(crate) checks: IndexSet<Check>,
+    pub(crate) runners: IndexSet<CheckRunner>,
     pub(crate) ignore: Ignore,
     enabled: IndexSet<ReportKind>,
     exit: IndexSet<ReportKind>,
@@ -215,7 +215,7 @@ impl ScannerRun {
             force: scanner.force,
             jobs: bounded_jobs(scanner.jobs),
             filters: scanner.filters.clone(),
-            checks: Default::default(),
+            runners: Default::default(),
             ignore: Ignore::new(repo),
             enabled: Default::default(),
             exit: Default::default(),
@@ -266,7 +266,7 @@ mod tests {
     use pkgcraft::test::*;
     use tracing_test::traced_test;
 
-    use crate::check::{Check, Context};
+    use crate::check::{CheckKind, Context};
     use crate::report::ReportLevel;
     use crate::test::*;
 
@@ -328,24 +328,26 @@ mod tests {
         assert!(reports > 0);
 
         // check
-        let scanner = Scanner::new().reports([Check::Dependency]);
+        let scanner = Scanner::new().reports([CheckKind::Dependency]);
         let expected = glob_reports!("{path}/Dependency/**/reports.json");
         let reports = scanner.run(repo, repo).unwrap();
         assert_unordered_reports!(reports, expected);
 
         // filter failure
         let latest = "latest".parse().unwrap();
-        let scanner = Scanner::new().reports([Check::Filesdir]).filters([latest]);
+        let scanner = Scanner::new()
+            .reports([CheckKind::Filesdir])
+            .filters([latest]);
         let result = scanner.run(repo, repo);
         assert_err_re!(result, "Filesdir: check requires no package filtering");
 
         // context failure
-        let scanner = Scanner::new().reports([Check::PythonUpdate]);
+        let scanner = Scanner::new().reports([CheckKind::PythonUpdate]);
         let result = scanner.run(repo, repo);
         assert_err_re!(result, "PythonUpdate: check requires gentoo-inherited context");
 
         // scope failure
-        let scanner = Scanner::new().reports([Check::Filesdir]);
+        let scanner = Scanner::new().reports([CheckKind::Filesdir]);
         let result = scanner.run(repo, "Filesdir/FilesUnused-0");
         assert_err_re!(result, "FilesUnused: report requires package scope");
 
@@ -491,7 +493,7 @@ mod tests {
         assert!(scanner.failed());
 
         // fail on specified check variant
-        let scanner = scanner.exit([Check::Dependency]);
+        let scanner = scanner.exit([CheckKind::Dependency]);
         scanner.run(repo, repo).unwrap().count();
         assert!(scanner.failed());
 
