@@ -1,19 +1,22 @@
 use std::{env, fs};
 
 use pkgcraft::repo::ebuild::EbuildRepoBuilder;
-use pkgcraft::test::*;
-use pkgcruft::test::*;
+use pkgcraft::test::{assert_ordered_eq, assert_unordered_eq, test_data, test_data_path};
 use predicates::prelude::*;
 use predicates::str::contains;
 use pretty_assertions::assert_eq;
-use tempfile::{tempdir, NamedTempFile};
+use tempfile::{NamedTempFile, tempdir};
+
+use crate::cmd;
+use crate::test::*;
 
 #[test]
 fn no_matches() {
-    cmd("pkgcruft scan nonexistent/pkg")
+    // no repo targets or configured repos
+    cmd("pkgcruft scan pkg")
         .assert()
         .stdout("")
-        .stderr(contains("no matches found: nonexistent/pkg"))
+        .stderr(contains("no repos available"))
         .failure()
         .code(2);
 
@@ -29,7 +32,7 @@ fn no_matches() {
 
     // specific targets in an empty repo fail
     cmd("pkgcruft scan cat/pkg")
-        .args(["--repo", repo.as_ref()])
+        .args(["--repo", repo.path().as_str()])
         .assert()
         .stdout("")
         .stderr(contains("no matches found: cat/pkg"))
@@ -56,7 +59,7 @@ fn stdin_targets() {
 
     for arg in ["KeywordsDropped", "KeywordsDropped/KeywordsDropped"] {
         cmd("pkgcruft scan -R simple -")
-            .args(["--repo", repo.as_ref()])
+            .args(["--repo", repo.path().as_str()])
             .write_stdin(format!("{arg}\n"))
             .assert()
             .stdout(contains("KeywordsDropped: x86"))
@@ -84,7 +87,7 @@ fn dep_restrict_targets() {
     // single
     for s in ["KeywordsDropped/*", "KeywordsDropped"] {
         cmd("pkgcruft scan -R simple")
-            .args(["--repo", repo.as_ref()])
+            .args(["--repo", repo.path().as_str()])
             .arg(s)
             .assert()
             .stdout(contains("KeywordsDropped: x86"))
@@ -98,7 +101,7 @@ fn dep_restrict_targets() {
     "#};
     let expected: Vec<_> = reports.lines().collect();
     let output = cmd("pkgcruft scan -R simple")
-        .args(["--repo", repo.as_ref()])
+        .args(["--repo", repo.path().as_str()])
         .args(["KeywordsDropped/*", "KeywordsDropped"])
         .output()
         .unwrap()
@@ -109,7 +112,7 @@ fn dep_restrict_targets() {
 
     // nonexistent
     cmd("pkgcruft scan -R simple")
-        .args(["--repo", repo.as_ref()])
+        .args(["--repo", repo.path().as_str()])
         .arg("nonexistent/pkg")
         .assert()
         .stdout("")
@@ -289,7 +292,7 @@ fn color() {
           KeywordsDropped: version 2: x86
     "};
     let expected: Vec<_> = reports.lines().collect();
-    let output = cmd("pkgcruft scan --color false")
+    let output = cmd("pkgcruft scan --color never")
         .args(["--repo", repo.as_ref()])
         .arg("KeywordsDropped")
         .output()
@@ -301,11 +304,11 @@ fn color() {
 
     // forcibly enable color
     let reports = indoc::indoc! {"
-        \u{1b}[1;34mKeywordsDropped/KeywordsDropped\u{1b}[0m
-          \u{1b}[33mKeywordsDropped\u{1b}[0m: version 2: x86
+        \u{1b}[94mKeywordsDropped/KeywordsDropped\u{1b}[39m
+          \u{1b}[33mKeywordsDropped\u{1b}[39m: version 2: x86
     "};
     let expected: Vec<_> = reports.lines().collect();
-    let output = cmd("pkgcruft scan --color true")
+    let output = cmd("pkgcruft scan --color always")
         .args(["--repo", repo.as_ref()])
         .arg("KeywordsDropped")
         .output()
@@ -756,7 +759,7 @@ fn reporter() {
             .code(2);
 
         // valid
-        for reporter in ["count", "fancy", "json", "simple"] {
+        for reporter in ["count", "fancy", "json", "simple", "time"] {
             cmd("pkgcruft scan")
                 .args([opt, reporter])
                 .assert()
